@@ -34,6 +34,11 @@ def test_which_ls():
 def test_echo_hello():
     assert check_parse('echo hello')
 
+
+def test_echo_star_with_semi():
+    assert check_parse('echo * spam ; ![echo eggs]\n')
+
+
 def test_simple_func():
     code = ('def prompt():\n'
             "    return '{user}'.format(user='me')\n")
@@ -63,12 +68,12 @@ def test_bad_indent():
         check_parse(code)
 
 def test_good_rhs_subproc():
-    # nonsense but parsebale
+    # nonsense but parsable
     code = 'str().split() | ![grep exit]\n'
     assert(code)
 
 def test_bad_rhs_subproc():
-    # nonsense but unparsebale
+    # nonsense but unparsable
     code = 'str().split() | grep exit\n'
     with pytest.raises(SyntaxError):
         check_parse(code)
