@@ -13,13 +13,26 @@ from xonsh.completers.tools import get_filter_function
 
 @xl.lazyobject
 def PATTERN_NEED_QUOTES():
-    pattern = r'\s`\$\{\}\,\*\(\)"\'\?&'
+    pattern = r'\s`\$\{\}\,\*\(\)"\'\?&#'
     if xp.ON_WINDOWS:
         pattern += '%'
     pattern = '[' + pattern + ']' + r'|\band\b|\bor\b'
     return re.compile(pattern)
 
 
+def cd_in_command(line):
+    """Returns True if "cd" is a token in the line, False otherwise."""
+    lexer = builtins.__xonsh_execer__.parser.lexer
+    lexer.reset()
+    lexer.input(line)
+    have_cd = False
+    for tok in lexer:
+        if tok.type == 'NAME' and tok.value == 'cd':
+            have_cd = True
+            break
+    return have_cd
+
+
 def _path_from_partial_string(inp, pos=None):
     if pos is None:
         pos = len(inp)
@@ -164,7 +177,7 @@ def _quote_paths(paths, start, end, append_end=True):
             s = s.replace(end, ''.join('\\%s' % i for i in end))
         s = start + s + end if append_end else start + s
         out.add(s)
-    return out
+    return out, need_quotes
 
 
 def _joinpath(path):
@@ -295,13 +308,13 @@ def complete_path(prefix, line, start, end, ctx, cdpath=True, filtfunc=None):
     if tilde in prefix:
         home = os.path.expanduser(tilde)
         paths = {s.replace(home, tilde) for s in paths}
-    if cdpath:
+    if cdpath and cd_in_command(line):
         _add_cdpaths(paths, prefix)
     paths = set(filter(filtfunc, paths))
-    paths = _quote_paths({_normpath(s) for s in paths},
-                         path_str_start,
-                         path_str_end,
-                         append_end)
+    paths, _ = _quote_paths({_normpath(s) for s in paths},
+                            path_str_start,
+                            path_str_end,
+                            append_end)
     paths.update(filter(filtfunc, _dots(prefix)))
     paths.update(filter(filtfunc, _env(prefix)))
     return paths, lprefix
